@@ -1,6 +1,7 @@
 import os
 import tensorflow as tf
 from . context import Context
+from . colab import IS_ON_COLABOLATORY_WITH_GOOGLE_DRIVE, Colaboratory
 
 def ENABLE_SUSPEND_RESUME_TRAIN():
     context = Context.get_instance()
@@ -37,15 +38,16 @@ class ResumeExecutor():
         splited = s.split(",")
         epoch = int(splited[0])
         lr = float(splited[1])
-        end = (splited[2]=="True")
+        best = float(splited[2])
+        end = (splited[3]=="True")
         f.close()
-        ret = (epoch,lr,end)
+        ret = (epoch,lr,best,end)
         # print(ret)
         return ret
 
     def is_train_ended(self)->bool:
         if tf.io.gfile.exists(self.path) == True:
-            _, _, end =self._load_values()
+            _, _, _, end =self._load_values()
             return end
         else:
             return False
@@ -73,19 +75,30 @@ class ResumeExecutor():
     def resume_model(self,model:tf.keras.Model):
         model.load_weights(self._get_model_path())
 
-    def suspend(self,epoch,lr,model):
-        # print("\nSusupend!!!")
+    def suspend(self,epoch,lr,best,model):
+        print("\nSusupend!!!")
         self._check_dir()
-        f = tf.io.gfile.GFile(self._get_resume_path(), mode="w")
-        resume_info = f.write(str(epoch)+","+str(lr)+"," +str(False))
+        file = self._get_resume_path()
+        f = tf.io.gfile.GFile(file, mode="w")
+        c = str(epoch)+","+str(lr)+"," + str(best) + "," +str(False)
+        print("suspend ",file,c)
+        resume_info = f.write(c)
+        f.flush()
         f.close()
         if model != None:
             model.save_weights(self._get_model_path())
+        
+        if IS_ON_COLABOLATORY_WITH_GOOGLE_DRIVE():
+            Colaboratory.copy_suspend_data_from_colab()
 
     def training_completed(self):
         self._check_dir()
         f = tf.io.gfile.GFile(self._get_resume_path(), mode="w")
-        resume_info = f.write(str(0)+","+str(0)+"," +str(True))
+        resume_info = f.write(str(0)+","+str(0.0)+"," +str(0.0)+","+ str(True))
         f.close()
+        
+        if IS_ON_COLABOLATORY_WITH_GOOGLE_DRIVE():
+            Colaboratory.copy_suspend_data_from_colab()
+
 
 
